@@ -42,6 +42,7 @@ class ImageData(DataClassJsonMixin):
   source_image_id: typing.Optional[str]
 
   job_id: str
+  reported: bool = False
   uri: typing.Optional[str] = None
   image_bytes: typing.Optional[bytearray] = None
   creation_time: datetime = datetime.now()
@@ -80,6 +81,7 @@ class Job(DataClassJsonMixin):
   image2image_params: typing.Optional[Image2ImageParams] = None
 
   creation_time: datetime = datetime.now()
+  reported: bool = False
   status: typing.Optional[JobStatus] = None
 
 
@@ -93,7 +95,7 @@ class Filter(DataClassJsonMixin):
   ddim_steps: int
   scale: float 
   strength: float
-  
+  is_premium: bool = False
   user_secret_id: typing.Optional[str] = None
   creation_time: datetime = datetime.now()
 
